pub struct SampleRect {
pub source_region: RectU16,
pub transform: Affine,
}Expand description
A rectangular source region sampled from an image input (e.g., crate::TextureId), paired
with a transform of the rectangle into the destination.
Fields
source_region: RectU16Source region in texel coordinates.
transform: AffineTransform mapping the local source region to the destination.
This maps from the local rectangle into the destination, ignoring the origin of
Self::source_region.